<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="pl">
<context>
    <name>ClientSSL</name>
    <message>
        <location filename="../clientssl.cpp" line="248"/>
        <source>Connected to host</source>
        <translation type="obsolete">Połączono z hostem</translation>
    </message>
    <message>
        <location filename="../clientssl.cpp" line="264"/>
        <source>Socket error</source>
        <translation type="obsolete">Błąd połączenia</translation>
    </message>
    <message>
        <location filename="../clientssl.cpp" line="277"/>
        <source>Connection closed</source>
        <translation type="obsolete">Połączenie zakończone</translation>
    </message>
    <message>
        <location filename="../clientssl.cpp" line="143"/>
        <source>Host not found !</source>
        <translation type="obsolete">Nie znaleziono hosta!</translation>
    </message>
    <message>
        <location filename="../clientssl.cpp" line="118"/>
        <source>Connection in progress on %1</source>
        <translation type="obsolete">Trwa łączenie z %1</translation>
    </message>
</context>
<context>
    <name>ClientSocket</name>
    <message>
        <location filename="../clientsocket.cpp" line="434"/>
        <source>Properties</source>
        <translation type="obsolete">Właściwości</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="408"/>
        <source>Send out message to all users</source>
        <translation type="obsolete">Wyślij wiadomość do wszystkich użytkowników</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="418"/>
        <source>Send out message to</source>
        <translation type="obsolete">Wyślij wiadomość do</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="428"/>
        <source>Disconnect user</source>
        <translation type="obsolete">Odłącz użytkownika</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="562"/>
        <source>&amp;Yes</source>
        <translation type="obsolete">&amp;Tak</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="562"/>
        <source>&amp;No</source>
        <translation type="obsolete">&amp;Nie</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="499"/>
        <source>Message to send</source>
        <translation type="obsolete">Wiadomość do wysłania</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="527"/>
        <source>Message to send to %1:</source>
        <translation type="obsolete">Wiadomość do wysłania do %1:</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="561"/>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation type="obsolete">Czy na pewno odłączyć użytkownika %1?</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="153"/>
        <source>Host not found !</source>
        <translation type="obsolete">Nie znaleziono hosta!</translation>
    </message>
</context>
<context>
    <name>LogForm</name>
    <message>
        <location filename="../log.cpp" line="82"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="82"/>
        <source>Machine</source>
        <translation>Komputer</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="82"/>
        <source>User</source>
        <translation>Użytkownik</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="82"/>
        <source>Service</source>
        <translation>Zasób</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="108"/>
        <source>Open File</source>
        <translation>Otwórz plik</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="82"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <location filename="../mainwindows.cpp" line="68"/>
        <source>QtSmbstatus Client</source>
        <translation type="obsolete">Klient QtSmbstatus</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="86"/>
        <source>Show CIFS/SMB activities</source>
        <translation>Pokaż dziennik zdarzeń CIFS/SMB</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="88"/>
        <source>Configure</source>
        <translation>Konfiguracja</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="172"/>
        <source>Minimize</source>
        <translation>Minimalizuj</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="93"/>
        <source>Quit</source>
        <translation>Zakończ</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="170"/>
        <source>Restore</source>
        <translation>Przywróć</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="245"/>
        <source>Thanks to:</source>
        <translation>Podziękowania:</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="259"/>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation>Ten program jest licencjonowany na zasadach GNU General Public License wersja 2</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="291"/>
        <source>Find text</source>
        <translation>Znajdź tekst</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="342"/>
        <source>Text not found.</source>
        <translation>Nie odnaleziono tekstu.</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="380"/>
        <source>User %1 has opened share %2 (%3)</source>
        <translation>Użytkownik %1 otworzył udział %2 (%3)</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="381"/>
        <source>User %1 has opened file %2 (%3)</source>
        <translation>Użytkownik %1 otworzył plik %2 (%3)</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="392"/>
        <source>CIFS/SMB activities</source>
        <translation>Zdarzenia CIFS/SMB</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="504"/>
        <source>Message to send</source>
        <translation>Wiadomość do wysłania</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="532"/>
        <source>Message to send to %1:</source>
        <translation>Wiadomość do wysłania do %1:</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="563"/>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Czy na pewno odłączyć użytkownika %1?</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="564"/>
        <source>&amp;Yes</source>
        <translation>&amp;Tak</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="564"/>
        <source>&amp;No</source>
        <translation>&amp;Nie</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="618"/>
        <source>Properties</source>
        <translation>Właściwości</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="592"/>
        <source>Send out message to all users</source>
        <translation>Wyślij wiadomość do wszystkich użytkowników</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="602"/>
        <source>Send out message to</source>
        <translation>Wyślij wiadomość do</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="612"/>
        <source>Disconnect user</source>
        <translation>Odłącz użytkownika</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="720"/>
        <source>Update is available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="723"/>
        <source>A new release of %1 is available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="725"/>
        <source>You can download it here: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <location filename="../configure.ui" line="19"/>
        <source>Configure</source>
        <translation>Konfiguracja</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="325"/>
        <source>Autoconnect</source>
        <translation>Łącz automatycznie</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="332"/>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Domyślny adres hosta:&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="309"/>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Domyślna nazwa użytkownika:&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="355"/>
        <source>Host Address</source>
        <translation>Adres Hosta</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="62"/>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Odstęp czasu:&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="238"/>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="215"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="345"/>
        <source>Username (default :  username = root)</source>
        <translation>Użytkownik (domyślnie:  username = root)</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="190"/>
        <source>Log SMB/CIFS activities</source>
        <translation>Rejestruj aktywne połączenia SMB/CIFS</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="180"/>
        <source>Status notification messages</source>
        <translation>Powiadomienia o zmianie stanu</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="107"/>
        <source>Notifications and log</source>
        <translation>Powiadomienia i rejestrowanie</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="125"/>
        <source>Limit log:</source>
        <translation>Ograniczenie wielkości dziennika:</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="154"/>
        <source>days</source>
        <translation>dni</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="170"/>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation>Minimalizuj na tackę systemową</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="31"/>
        <source>Smbstatus</source>
        <translation>Smbstatus</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="75"/>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation>Odstęp między kolejnymi połączeniami (s, co najmniej 2)</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="88"/>
        <source>Show hidden shares (share$)</source>
        <translation>Pokaż ukryte udziały (share$)</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="91"/>
        <source>Show hidden shares</source>
        <translation>Pokaż ukryte udziały</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="291"/>
        <source>Connection</source>
        <translation>Połączenie</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="322"/>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation>Łącz automatycznie podczas uruchamiania</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="177"/>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation>Pokazuj wykonywane czynności w podpowiedziach</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="256"/>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="265"/>
        <source>Automatically Check for updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="272"/>
        <source>A new release is available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <location filename="../form_smbstatus.ui" line="13"/>
        <source>qtsmbstatus</source>
        <translation>qtsmbstatus</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="167"/>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="188"/>
        <source>&amp;About QtSmbstatus</source>
        <translation>&amp;O QtSmbstatus</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="205"/>
        <source>About &amp;Qt</source>
        <translation>O &amp;Qt</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="117"/>
        <source>Connect/Disconnect</source>
        <translation>Połącz/Rozłącz</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="61"/>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="223"/>
        <source>&amp;Configure client</source>
        <translation>&amp;Konfiguracja klienta</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="159"/>
        <source>&amp;Search</source>
        <translation>&amp;Znajdź</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="234"/>
        <source>&amp;Machine</source>
        <translation>&amp;Komputer</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="245"/>
        <source>&amp;User</source>
        <translation>&amp;Użytkownik</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="256"/>
        <source>Share &amp;open</source>
        <translation>&amp;Otwarty udział</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="267"/>
        <source>&amp;Locked file</source>
        <translation>&amp;Zablokowany plik</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="278"/>
        <source>&amp;Next</source>
        <translation>&amp;Znajdź następne</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="284"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="292"/>
        <source>&amp;Find text</source>
        <translation>Znajdź &amp;tekst</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="298"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="148"/>
        <source>&amp;File</source>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="208"/>
        <source>About Qt</source>
        <translation>O Qt</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="226"/>
        <source>Configure QtSmbstatus client</source>
        <translation>Konfiguracja QtSmbstatus</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="237"/>
        <source>Search machine</source>
        <translation>Znajdź komputer</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="248"/>
        <source>Search user</source>
        <translation>Znajdź użytkownika</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="259"/>
        <source>Search share open</source>
        <translation>Znajdź otwarty udział</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="270"/>
        <source>Search file open</source>
        <translation>Znajdź otwarty plik</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="281"/>
        <source>Next</source>
        <translation>Dalej</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="295"/>
        <source>Find text</source>
        <translation>Znajdź tekst</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="307"/>
        <source>&amp;Quit</source>
        <translation>Za&amp;kończ</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="310"/>
        <source>Quit QtSmbstatus</source>
        <translation>Zakończ QtSmbstatus</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="324"/>
        <source>Co&amp;nnect</source>
        <translation>&amp;Połącz</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="315"/>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation>P&amp;okaż dziennik zdarzeń CIFS/SMB</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="191"/>
        <source>About QtSmbstatus</source>
        <translation>O QtSmbstatus</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <location filename="../log.ui" line="13"/>
        <source>View Activities</source>
        <translation>Dziennik zdarzeń</translation>
    </message>
    <message>
        <location filename="../log.ui" line="124"/>
        <source>View/hide shares</source>
        <translation>Pokaż lub ukryj udziały</translation>
    </message>
    <message>
        <location filename="../log.ui" line="156"/>
        <source>View/hide files</source>
        <translation>Pokaż lub ukryj pliki</translation>
    </message>
    <message>
        <location filename="../log.ui" line="196"/>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
    <message>
        <location filename="../log.ui" line="41"/>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
    <message>
        <location filename="../log.ui" line="104"/>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <location filename="../log.ui" line="70"/>
        <source>Save log</source>
        <translation>Zapisz dziennik</translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <location filename="../login_dialog.ui" line="120"/>
        <source>login</source>
        <translation>Login</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="149"/>
        <source>exit</source>
        <translation>Wyjście</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="27"/>
        <source>Username</source>
        <translation>Użytkownik</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="49"/>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="62"/>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="13"/>
        <source>Connect to qtsmbstatus server</source>
        <translation>Połącz z serwerem</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <location filename="../main_windows.cpp" line="533"/>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation type="obsolete">Ten program jest licencjonowany na zasadach GNU General Public License wersja 2</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="488"/>
        <source>Search share</source>
        <translation type="obsolete">Znajdź udział</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="497"/>
        <source>Search locked file</source>
        <translation type="obsolete">Znajdź zablokowany plik</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="627"/>
        <source>Text not found.</source>
        <translation type="obsolete">Nie odnaleziono tekstu.</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="70"/>
        <source>QtSmbstatus Client</source>
        <translation type="obsolete">Klient QtSmbstatus</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="310"/>
        <source>Connect</source>
        <translation>Połącz</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="177"/>
        <source>Minimize</source>
        <translation type="obsolete">Minimalizuj</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="82"/>
        <source>Quit</source>
        <translation type="obsolete">Zakończ</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="175"/>
        <source>Restore</source>
        <translation type="obsolete">Przywróć</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="305"/>
        <source>Disconnect</source>
        <translation>Rozłącz</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="665"/>
        <source>User %1 has opened share %2 (%3)</source>
        <translation type="obsolete">Użytkownik %1 otworzył udział %2 (%3)</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="666"/>
        <source>User %1 has opened file %2 (%3)</source>
        <translation type="obsolete">Użytkownik %1 otworzył plik %2 (%3)</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="75"/>
        <source>Show CIFS/SMB activities</source>
        <translation type="obsolete">Pokaż dziennik zdarzeń CIFS/SMB</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="91"/>
        <source>Impossible to know samba version</source>
        <translation type="obsolete">Nie można ustalić wersji Samby</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="356"/>
        <source>Invalid login or password !</source>
        <translation>Nieprawidłowa nazwa użytkownika lub hasło!</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="677"/>
        <source>CIFS/SMB activities</source>
        <translation type="obsolete">Zdarzenia CIFS/SMB</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="519"/>
        <source>Thanks to:</source>
        <translation type="obsolete">Podziękowania:</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="77"/>
        <source>Configure</source>
        <translation type="obsolete">Konfiguracja</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="576"/>
        <source>Find text</source>
        <translation type="obsolete">Znajdź tekst</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="469"/>
        <source>Search machine</source>
        <translation type="obsolete">Znajdź komputer</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="479"/>
        <source>Search user</source>
        <translation type="obsolete">Znajdź użytkownika</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="198"/>
        <source>Connection in progress on %1</source>
        <translation>Trwa łączenie z %1</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="223"/>
        <source>Connected to host</source>
        <translation>Połączono z hostem</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="241"/>
        <source>Connection closed</source>
        <translation>Połączenie zakończone</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="965"/>
        <source>Properties</source>
        <translation type="obsolete">Właściwości</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="939"/>
        <source>Send out message to all users</source>
        <translation type="obsolete">Wyślij wiadomość do wszystkich użytkowników</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="949"/>
        <source>Send out message to</source>
        <translation type="obsolete">Wyślij wiadomość do</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="959"/>
        <source>Disconnect user</source>
        <translation type="obsolete">Odłącz użytkownika</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="1031"/>
        <source>Message to send</source>
        <translation type="obsolete">Wiadomość do wysłania</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="1057"/>
        <source>Message to send to %1:</source>
        <translation type="obsolete">Wiadomość do wysłania do %1:</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="1089"/>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation type="obsolete">Czy na pewno odłączyć użytkownika %1?</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="1090"/>
        <source>&amp;Yes</source>
        <translation type="obsolete">&amp;Tak</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="1090"/>
        <source>&amp;No</source>
        <translation type="obsolete">&amp;Nie</translation>
    </message>
</context>
</TS>
